<?php
namespace Saltus\WP\Plugin\Saltus\InteractiveMaps\Plugin;

/**
 * Defines the list of available maps
 */
class MapList {

	public $maps;

	public function __construct() {
		$this->add_filters();
		$this->set_maps();
	}

	public function add_filters() {

		add_filter(
			'igm_map_list_json',
			function( $json ) {
				$converted = json_decode( $json, true );

				// to add this to the end of the list
				$options = $converted;

				$options[ __( 'Portugal Maps' ) ] = [
					'custom_cmoreira_portugalLisboaFreguesias'     => 'Portugal - Freguesias Lisboa (23kb)',
					'custom_cmoreira_portugalPortoFreguesias'      => 'Portugal - Freguesias Porto (12kb)',
					'custom_cmoreira_portugalModifiedDistricts'    => 'Portugal - Districts Viewport (73kb)',
					'custom_cmoreira_portugalModifiedMunicipios'   => 'Portugal -  Municipios Viewport - Incomplete (369kb)',
					'custom_cmoreira_portugalModifiedConcelhos'    => 'Portugal -  Concelhos Viewport (576kb)',
					'custom_cmoreira_portugalModifiedConcelhosLow' => 'Portugal -  Concelhos Viewport Low (323kb)',
				];

				return json_encode( $options );
			}
		);

	}

	public function set_maps() {
		$json = '{
			"World, Regions & Continents": {
				"region\/world\/africaHigh": "Africa High (79kb)",
				"region\/world\/africaLow": "Africa Low (37kb)",
				"region\/world\/africaUltra": "Africa Ultra (185kb)",
				"region\/world\/asiaHigh": "Asia High (161kb)",
				"region\/world\/asiaLow": "Asia Low (63kb)",
				"region\/world\/asiaUltra": "Asia Ultra (403kb)",
				"region\/world\/caribbeanHigh": "Caribbean High (13kb)",
				"region\/world\/caribbeanLow": "Caribbean Low (9kb)",
				"region\/world\/caribbeanUltra": "Caribbean Ultra (24kb)",
				"region\/world\/centralAmericaHigh": "Central America High (13kb)",
				"region\/world\/centralAmericaLow": "Central America Low (5kb)",
				"region\/world\/europeHigh": "Europe High (106kb)",
				"region\/world\/europeLow": "Europe Low (45kb)",
				"region\/world\/europeUltra": "Europe Ultra (253kb)",
				"region\/world\/latinAmericaHigh": "Latin America High (78kb)",
				"region\/world\/latinAmericaLow": "Latin America Low (34kb)",
				"region\/world\/latinAmericaUltra": "Latin America Ultra (185kb)",
				"region\/world\/middleEastHigh": "Middle East High (16kb)",
				"region\/world\/middleEastLow": "Middle East Low (7kb)",
				"region\/world\/middleEastUltra": "Middle East Ultra (36kb)",
				"region\/world\/northAmericaHigh": "North America High (141kb)",
				"region\/world\/northAmericaLow": "North America Low (55kb)",
				"region\/world\/northAmericaUltra": "North America Ultra (351kb)",
				"region\/world\/oceaniaHigh": "Oceania High (52kb)",
				"region\/world\/oceaniaLow": "Oceania Low (20kb)",
				"region\/world\/oceaniaUltra": "Oceania Ultra (128kb)",
				"region\/world\/southAmericaHigh": "South America High (51kb)",
				"region\/world\/southAmericaLow": "South America Low (20kb)",
				"region\/world\/southAmericaUltra": "South America Ultra (130kb)",
				"region\/world\/worldRegionsHigh": "World Regions High (357kb)",
				"region\/world\/worldRegionsLow": "World Regions Low (121kb)",
				"region\/world\/worldRegionsUltra": "World Regions Ultra (935kb)",
				"continentsHigh": "Continents High (351kb)",
				"continentsLow": "Continents Low (118kb)",
				"continentsRussiaAsiaHigh": "Continents Russia Asia High (355kb)",
				"continentsRussiaAsiaLow": "Continents Russia Asia Low (120kb)",
				"continentsRussiaAsiaUltra": "Continents Russia Asia Ultra (931kb)",
				"continentsRussiaEuropeHigh": "Continents Russia Europe High (363kb)",
				"continentsRussiaEuropeLow": "Continents Russia Europe Low (123kb)",
				"continentsRussiaEuropeUltra": "Continents Russia Europe Ultra (952kb)",
				"continentsUltra": "Continents Ultra (924kb)",
				"worldChinaHigh": "World China High (608kb)",
				"worldChinaLow": "World China Low (246kb)",
				"worldChinaUltra": "World China Ultra (1mb)",
				"worldGreatLakesHigh": "World Great Lakes High (610kb)",
				"worldGreatLakesLow": "World Great Lakes Low (247kb)",
				"worldGreatLakesUltra": "World Great Lakes Ultra (1mb)",
				"worldHigh": "World High (603kb)",
				"worldIndiaHigh": "World India High (604kb)",
				"worldIndiaLow": "World India Low (245kb)",
				"worldIndiaUltra": "World India Ultra (1mb)",
				"worldLow": "World Low (244kb)",
				"worldMoroccoHigh": "World Morocco High (610kb)",
				"worldMoroccoLow": "World Morocco Low (247kb)",
				"worldMoroccoUltra": "World Morocco Ultra (1mb)",
				"worldRussiaHigh": "World Russia High (610kb)",
				"worldRussiaLow": "World Russia Low (247kb)",
				"worldRussiaUltra": "World Russia Ultra (1mb)",
				"worldTimeZoneAreasHigh": "World Time Zone Areas High (482kb)",
				"worldTimeZoneAreasLow": "World Time Zone Areas Low (179kb)",
				"worldTimeZoneAreasUltra": "World Time Zone Areas Ultra (1mb)",
				"worldTimeZonesHigh": "World Time Zones High (876kb)",
				"worldTimeZonesLow": "World Time Zones Low (337kb)",
				"worldTimeZonesUltra": "World Time Zones Ultra (2mb)",
				"worldUltra": "World Ultra (1mb)"
			},
			"Countries": {
				"albaniaHigh": "Albania High (37kb)",
				"albaniaLow": "Albania Low (16kb)",
				"algeriaHigh": "Algeria High (127kb)",
				"algeriaLow": "Algeria Low (55kb)",
				"americanSamoaHigh": "American Samoa High (44kb)",
				"americanSamoaLow": "American Samoa Low (17kb)",
				"andorraHigh": "Andorra High (19kb)",
				"andorraLow": "Andorra Low (8kb)",
				"angolaHigh": "Angola High (69kb)",
				"angolaLow": "Angola Low (30kb)",
				"anguillaHigh": "Anguilla High (51kb)",
				"anguillaLow": "Anguilla Low (24kb)",
				"antiguaBarbudaHigh": "Antigua Barbuda High (39kb)",
				"antiguaBarbudaLow": "Antigua Barbuda Low (17kb)",
				"argentinaHigh": "Argentina High (77kb)",
				"argentinaLow": "Argentina Low (33kb)",
				"armeniaHigh": "Armenia High (24kb)",
				"armeniaLow": "Armenia Low (11kb)",
				"arubaHigh": "Aruba High (11kb)",
				"arubaLow": "Aruba Low (4kb)",
				"australiaHigh": "Australia High (43kb)",
				"australiaLow": "Australia Low (18kb)",
				"austriaHigh": "Austria High (181kb)",
				"austriaLow": "Austria Low (70kb)",
				"azerbaijanHigh": "Azerbaijan High (178kb)",
				"azerbaijanLow": "Azerbaijan Low (79kb)",
				"bahamasHigh": "Bahamas High (38kb)",
				"bahamasLow": "Bahamas Low (19kb)",
				"bahrainHigh": "Bahrain High (34kb)",
				"bahrainLow": "Bahrain Low (14kb)",
				"bangladeshHigh": "Bangladesh High (60kb)",
				"bangladeshLow": "Bangladesh Low (25kb)",
				"barbadosHigh": "Barbados High (18kb)",
				"barbadosLow": "Barbados Low (9kb)",
				"belarusHigh": "Belarus High (55kb)",
				"belarusLow": "Belarus Low (21kb)",
				"belgiumHigh": "Belgium High (151kb)",
				"belgiumLow": "Belgium Low (58kb)",
				"belizeHigh": "Belize High (61kb)",
				"belizeLow": "Belize Low (24kb)",
				"beninHigh": "Benin High (78kb)",
				"beninLow": "Benin Low (31kb)",
				"bermudaHigh": "Bermuda High (39kb)",
				"bermudaLow": "Bermuda Low (17kb)",
				"bhutanHigh": "Bhutan High (50kb)",
				"bhutanLow": "Bhutan Low (22kb)",
				"boliviaHigh": "Bolivia High (20kb)",
				"boliviaLow": "Bolivia Low (9kb)",
				"bonaireSintEustatiusSabaHigh": "Bonaire Sint Eustatius Saba High (5kb)",
				"bonaireSintEustatiusSabaLow": "Bonaire Sint Eustatius Saba Low (2kb)",
				"bosniaHerzegovinaCantonsHigh": "Bosnia Herzegovina Cantons High (27kb)",
				"bosniaHerzegovinaCantonsLow": "Bosnia Herzegovina Cantons Low (13kb)",
				"bosniaHerzegovinaHigh": "Bosnia Herzegovina High (17kb)",
				"bosniaHerzegovinaLow": "Bosnia Herzegovina Low (7kb)",
				"botswanaHigh": "Botswana High (54kb)",
				"botswanaLow": "Botswana Low (21kb)",
				"brazilHigh": "Brazil High (93kb)",
				"brazilLow": "Brazil Low (40kb)",
				"britishIndianOceanTerritoryHigh": "British Indian Ocean Territory High (166kb)",
				"britishIndianOceanTerritoryLow": "British Indian Ocean Territory Low (70kb)",
				"bruneiDarussalamHigh": "Brunei Darussalam High (17kb)",
				"bruneiDarussalamLow": "Brunei Darussalam Low (7kb)",
				"bulgariaHigh": "Bulgaria High (88kb)",
				"bulgariaLow": "Bulgaria Low (38kb)",
				"burkinaFasoHigh": "Burkina Faso High (33kb)",
				"burkinaFasoLow": "Burkina Faso Low (15kb)",
				"burundiHigh": "Burundi High (73kb)",
				"burundiLow": "Burundi Low (31kb)",
				"cambodiaHigh": "Cambodia High (2mb)",
				"cambodiaLow": "Cambodia Low (688kb)",
				"cameroonHigh": "Cameroon High (59kb)",
				"cameroonLow": "Cameroon Low (27kb)",
				"canadaHigh": "Canada High (223kb)",
				"canadaLow": "Canada Low (89kb)",
				"capeVerdeHigh": "Cape Verde High (41kb)",
				"capeVerdeLow": "Cape Verde Low (20kb)",
				"caymanIslandsHigh": "Cayman Islands High (17kb)",
				"caymanIslandsLow": "Cayman Islands Low (7kb)",
				"centralAfricanRepublicHigh": "Central African Republic High (53kb)",
				"centralAfricanRepublicLow": "Central African Republic Low (23kb)",
				"chadHigh": "Chad High (26kb)",
				"chadLow": "Chad Low (14kb)",
				"channelIslandsHigh": "Channel Islands High (38kb)",
				"channelIslandsLow": "Channel Islands Low (27kb)",
				"chileHigh": "Chile High (114kb)",
				"chileLow": "Chile Low (49kb)",
				"chinaHigh": "China High (201kb)",
				"chinaLow": "China Low (81kb)",
				"cocosKeelingHigh": "Cocos Keeling High (31kb)",
				"cocosKeelingLow": "Cocos Keeling Low (12kb)",
				"colombiaHigh": "Colombia High (73kb)",
				"colombiaLow": "Colombia Low (33kb)",
				"colombiaMuniHigh": "Colombia Muni High (2mb)",
				"colombiaMuniLow": "Colombia Muni Low (922kb)",
				"comorosHigh": "Comoros High (20kb)",
				"comorosLow": "Comoros Low (8kb)",
				"congoDRHigh": "Congo D R High (90kb)",
				"congoDRLow": "Congo D R Low (39kb)",
				"congoHigh": "Congo High (57kb)",
				"congoLow": "Congo Low (23kb)",
				"costaRicaHigh": "Costa Rica High (48kb)",
				"costaRicaLow": "Costa Rica Low (21kb)",
				"croatiaHigh": "Croatia High (61kb)",
				"croatiaLow": "Croatia Low (27kb)",
				"cubaHigh": "Cuba High (80kb)",
				"cubaLow": "Cuba Low (34kb)",
				"curacaoHigh": "Curacao High (1kb)",
				"curacaoLow": "Curacao Low (618bb)",
				"cyprusHigh": "Cyprus High (30kb)",
				"cyprusLow": "Cyprus Low (12kb)",
				"cyprusNorthCyprusHigh": "Cyprus North Cyprus High (43kb)",
				"cyprusNorthCyprusLow": "Cyprus North Cyprus Low (19kb)",
				"czechRepublicHigh": "Czech Republic High (301kb)",
				"czechRepublicLow": "Czech Republic Low (112kb)",
				"czechiaHigh": "Czechia High (301kb)",
				"czechiaLow": "Czechia Low (112kb)",
				"denmarkHigh": "Denmark High (73kb)",
				"denmarkLow": "Denmark Low (29kb)",
				"djiboutiHigh": "Djibouti High (13kb)",
				"djiboutiLow": "Djibouti Low (6kb)",
				"dominicaHigh": "Dominica High (76kb)",
				"dominicaLow": "Dominica Low (33kb)",
				"dominicanRepublicHigh": "Dominican Republic High (76kb)",
				"dominicanRepublicLow": "Dominican Republic Low (35kb)",
				"dominicanRepublicMuniHigh": "Dominican Republic Muni High (940kb)",
				"dominicanRepublicMuniLow": "Dominican Republic Muni Low (289kb)",
				"ecuadorHigh": "Ecuador High (93kb)",
				"ecuadorLow": "Ecuador Low (39kb)",
				"egyptHigh": "Egypt High (108kb)",
				"egyptLow": "Egypt Low (53kb)",
				"elSalvadorHigh": "EL Salvador High (59kb)",
				"elSalvadorLow": "EL Salvador Low (26kb)",
				"equatorialGuineaHigh": "Equatorial Guinea High (797kb)",
				"equatorialGuineaLow": "Equatorial Guinea Low (287kb)",
				"eritreaHigh": "Eritrea High (21kb)",
				"eritreaLow": "Eritrea Low (9kb)",
				"estoniaHigh": "Estonia High (96kb)",
				"estoniaLow": "Estonia Low (40kb)",
				"eswatiniHigh": "Eswatini High (40kb)",
				"eswatiniLow": "Eswatini Low (18kb)",
				"ethiopiaHigh": "Ethiopia High (59kb)",
				"ethiopiaLow": "Ethiopia Low (24kb)",
				"faroeIslandsHigh": "Faroe Islands High (9kb)",
				"faroeIslandsLow": "Faroe Islands Low (4kb)",
				"fijiEastHigh": "Fiji East High (5kb)",
				"fijiEastLow": "Fiji East Low (2kb)",
				"fijiWestHigh": "Fiji West High (24kb)",
				"fijiWestLow": "Fiji West Low (10kb)",
				"finlandHigh": "Finland High (169kb)",
				"finlandLow": "Finland Low (74kb)",
				"franceDepartmentsHigh": "France Departments High (158kb)",
				"franceDepartmentsLow": "France Departments Low (76kb)",
				"franceHigh": "France High (55kb)",
				"franceLow": "France Low (22kb)",
				"frenchGuianaHigh": "French Guiana High (28kb)",
				"frenchGuianaLow": "French Guiana Low (11kb)",
				"gabonHigh": "Gabon High (212kb)",
				"gabonLow": "Gabon Low (91kb)",
				"gambiaHigh": "Gambia High (22kb)",
				"gambiaLow": "Gambia Low (10kb)",
				"georgiaHigh": "Georgia High (72kb)",
				"georgiaLow": "Georgia Low (29kb)",
				"georgiaSouthOssetiaHigh": "Georgia South Ossetia High (74kb)",
				"georgiaSouthOssetiaLow": "Georgia South Ossetia Low (31kb)",
				"germanyHigh": "Germany High (665kb)",
				"germanyLow": "Germany Low (253kb)",
				"ghanaHigh": "Ghana High (53kb)",
				"ghanaLow": "Ghana Low (22kb)",
				"greeceHigh": "Greece High (106kb)",
				"greeceLow": "Greece Low (44kb)",
				"greenlandHigh": "Greenland High (166kb)",
				"greenlandLow": "Greenland Low (66kb)",
				"guatemalaHigh": "Guatemala High (343kb)",
				"guatemalaLow": "Guatemala Low (167kb)",
				"guineaBissauHigh": "Guinea Bissau High (35kb)",
				"guineaBissauLow": "Guinea Bissau Low (15kb)",
				"guineaHigh": "Guinea High (43kb)",
				"guineaLow": "Guinea Low (17kb)",
				"guyanaHigh": "Guyana High (36kb)",
				"guyanaLow": "Guyana Low (15kb)",
				"hondurasHigh": "Honduras High (79kb)",
				"hondurasLow": "Honduras Low (33kb)",
				"hongKongHigh": "Hong Kong High (75kb)",
				"hongKongLow": "Hong Kong Low (33kb)",
				"hungaryHigh": "Hungary High (54kb)",
				"hungaryLow": "Hungary Low (24kb)",
				"icelandHigh": "Iceland High (73kb)",
				"icelandLow": "Iceland Low (33kb)",
				"india2019High": "India2019 High (173kb)",
				"india2019Low": "India2019 Low (70kb)",
				"indiaHigh": "India High (170kb)",
				"indiaLow": "India Low (69kb)",
				"indonesiaHigh": "Indonesia High (167kb)",
				"indonesiaLow": "Indonesia Low (71kb)",
				"irelandHigh": "Ireland High (222kb)",
				"irelandLow": "Ireland Low (93kb)",
				"israelHigh": "Israel High (27kb)",
				"israelLow": "Israel Low (12kb)",
				"israelPalestineHigh": "Israel Palestine High (49kb)",
				"israelPalestineLow": "Israel Palestine Low (23kb)",
				"italyHigh": "Italy High (66kb)",
				"italyLow": "Italy Low (28kb)",
				"jamaicaHigh": "Jamaica High (15kb)",
				"jamaicaLow": "Jamaica Low (8kb)",
				"japanHigh": "Japan High (181kb)",
				"japanLow": "Japan Low (78kb)",
				"kazakhstanHigh": "Kazakhstan High (90kb)",
				"kazakhstanLow": "Kazakhstan Low (40kb)",
				"kenyaHigh": "Kenya High (4mb)",
				"kenyaLow": "Kenya Low (1mb)",
				"kosovoHigh": "Kosovo High (25kb)",
				"kosovoLow": "Kosovo Low (10kb)",
				"kuwaitHigh": "Kuwait High (13kb)",
				"kuwaitLow": "Kuwait Low (6kb)",
				"kyrgyzstanHigh": "Kyrgyzstan High (133kb)",
				"kyrgyzstanLow": "Kyrgyzstan Low (50kb)",
				"laosHigh": "Laos High (59kb)",
				"laosLow": "Laos Low (26kb)",
				"latviaHigh": "Latvia High (164kb)",
				"latviaLow": "Latvia Low (82kb)",
				"lebanonHigh": "Lebanon High (562kb)",
				"lebanonLow": "Lebanon Low (215kb)",
				"libyaHigh": "Libya High (31kb)",
				"libyaLow": "Libya Low (16kb)",
				"liechtensteinHigh": "Liechtenstein High (29kb)",
				"liechtensteinLow": "Liechtenstein Low (14kb)",
				"lithuaniaHigh": "Lithuania High (154kb)",
				"lithuaniaLow": "Lithuania Low (61kb)",
				"luxembourgHigh": "Luxembourg High (52kb)",
				"luxembourgLow": "Luxembourg Low (21kb)",
				"madagascarProvinceHigh": "Madagascar Province High (85kb)",
				"madagascarProvinceLow": "Madagascar Province Low (32kb)",
				"madagascarRegionHigh": "Madagascar Region High (99kb)",
				"madagascarRegionLow": "Madagascar Region Low (42kb)",
				"malawiHigh": "Malawi High (1mb)",
				"malawiLow": "Malawi Low (459kb)",
				"malaysiaHigh": "Malaysia High (86kb)",
				"malaysiaLow": "Malaysia Low (36kb)",
				"maldivesHigh": "Maldives High (62kb)",
				"maldivesIslandsHigh": "Maldives Islands High (499kb)",
				"maldivesIslandsLow": "Maldives Islands Low (226kb)",
				"maldivesLow": "Maldives Low (26kb)",
				"maliHigh": "Mali High (279kb)",
				"maliLow": "Mali Low (103kb)",
				"maltaHigh": "Malta High (15kb)",
				"maltaLow": "Malta Low (7kb)",
				"mauritaniaHigh": "Mauritania High (94kb)",
				"mauritaniaLow": "Mauritania Low (39kb)",
				"mexicoHigh": "Mexico High (180kb)",
				"mexicoLow": "Mexico Low (76kb)",
				"moldovaHigh": "Moldova High (45kb)",
				"moldovaLow": "Moldova Low (24kb)",
				"mongoliaHigh": "Mongolia High (160kb)",
				"mongoliaLow": "Mongolia Low (71kb)",
				"moroccoHigh": "Morocco High (196kb)",
				"moroccoLow": "Morocco Low (87kb)",
				"mozambiqueHigh": "Mozambique High (85kb)",
				"mozambiqueLow": "Mozambique Low (34kb)",
				"myanmarHigh": "Myanmar High (142kb)",
				"myanmarLow": "Myanmar Low (57kb)",
				"namibiaHigh": "Namibia High (53kb)",
				"namibiaLow": "Namibia Low (24kb)",
				"nepalHigh": "Nepal High (34kb)",
				"nepalLow": "Nepal Low (14kb)",
				"netherlandsHigh": "Netherlands High (120kb)",
				"netherlandsLow": "Netherlands Low (49kb)",
				"newZealandHigh": "New Zealand High (176kb)",
				"newZealandLow": "New Zealand Low (71kb)",
				"nicaraguaHigh": "Nicaragua High (79kb)",
				"nicaraguaLow": "Nicaragua Low (35kb)",
				"nigerHigh": "Niger High (28kb)",
				"nigerLow": "Niger Low (12kb)",
				"nigeriaHigh": "Nigeria High (83kb)",
				"nigeriaLow": "Nigeria Low (39kb)",
				"northKoreaHigh": "North Korea High (170kb)",
				"northKoreaLow": "North Korea Low (74kb)",
				"northMacedoniaHigh": "North Macedonia High (104kb)",
				"northMacedoniaLow": "North Macedonia Low (50kb)",
				"norwayHigh": "Norway High (301kb)",
				"norwayLow": "Norway Low (125kb)",
				"omanHigh": "Oman High (74kb)",
				"omanLow": "Oman Low (33kb)",
				"pakistanHigh": "Pakistan High (39kb)",
				"pakistanLow": "Pakistan Low (16kb)",
				"palestineHigh": "Palestine High (37kb)",
				"palestineLow": "Palestine Low (17kb)",
				"panamaHigh": "Panama High (53kb)",
				"panamaLow": "Panama Low (23kb)",
				"paraguayHigh": "Paraguay High (547kb)",
				"paraguayLow": "Paraguay Low (189kb)",
				"peruHigh": "Peru High (69kb)",
				"peruLow": "Peru Low (31kb)",
				"philippinesHigh": "Philippines High (117kb)",
				"philippinesLow": "Philippines Low (58kb)",
				"polandHigh": "Poland High (411kb)",
				"polandLow": "Poland Low (161kb)",
				"portugalHigh": "Portugal High (44kb)",
				"portugalLow": "Portugal Low (20kb)",
				"portugalRegionsHigh": "Portugal Regions High (29kb)",
				"portugalRegionsLow": "Portugal Regions Low (12kb)",
				"puertoRicoHigh": "Puerto Rico High (480kb)",
				"puertoRicoLow": "Puerto Rico Low (223kb)",
				"qatarHigh": "Qatar High (36kb)",
				"qatarLow": "Qatar Low (16kb)",
				"romaniaHigh": "Romania High (182kb)",
				"romaniaLow": "Romania Low (76kb)",
				"russiaCrimeaHigh": "Russia Crimea High (1mb)",
				"russiaCrimeaLow": "Russia Crimea Low (223kb)",
				"russiaHigh": "Russia High (1mb)",
				"russiaLow": "Russia Low (223kb)",
				"rwandaHigh": "Rwanda High (13kb)",
				"rwandaLow": "Rwanda Low (6kb)",
				"saintHelenaHigh": "Saint Helena High (86kb)",
				"saintHelenaLow": "Saint Helena Low (34kb)",
				"saintLuciaHigh": "Saint Lucia High (56kb)",
				"saintLuciaLow": "Saint Lucia Low (22kb)",
				"saintVincentHigh": "Saint Vincent High (34kb)",
				"saintVincentLow": "Saint Vincent Low (15kb)",
				"samoaHigh": "Samoa High (31kb)",
				"samoaLow": "Samoa Low (15kb)",
				"sanMarinoHigh": "San Marino High (21kb)",
				"sanMarinoLow": "San Marino Low (10kb)",
				"saoTomePrincipeHigh": "Sao Tome Principe High (21kb)",
				"saoTomePrincipeLow": "Sao Tome Principe Low (10kb)",
				"saudiArabiaHigh": "Saudi Arabia High (72kb)",
				"saudiArabiaLow": "Saudi Arabia Low (30kb)",
				"senegalHigh": "Senegal High (120kb)",
				"senegalLow": "Senegal Low (50kb)",
				"serbiaHigh": "Serbia High (54kb)",
				"serbiaLow": "Serbia Low (27kb)",
				"serbiaNoKosovoHigh": "Serbia No Kosovo High (47kb)",
				"serbiaNoKosovoLow": "Serbia No Kosovo Low (23kb)",
				"seychellesHigh": "Seychelles High (130kb)",
				"seychellesLow": "Seychelles Low (57kb)",
				"sierraLeoneHigh": "Sierra Leone High (27kb)",
				"sierraLeoneLow": "Sierra Leone Low (11kb)",
				"singaporeHigh": "Singapore High (82kb)",
				"singaporeLow": "Singapore Low (33kb)",
				"slovakiaHigh": "Slovakia High (119kb)",
				"slovakiaLow": "Slovakia Low (46kb)",
				"sloveniaHigh": "Slovenia High (4mb)",
				"sloveniaLow": "Slovenia Low (2mb)",
				"sloveniaRegionsHigh": "Slovenia Regions High (1mb)",
				"sloveniaRegionsLow": "Slovenia Regions Low (540kb)",
				"solomonIslandsHigh": "Solomon Islands High (384kb)",
				"solomonIslandsLow": "Solomon Islands Low (146kb)",
				"somaliaHigh": "Somalia High (43kb)",
				"somaliaLow": "Somalia Low (20kb)",
				"southAfricaHigh": "South Africa High (56kb)",
				"southAfricaLow": "South Africa Low (23kb)",
				"southKoreaHigh": "South Korea High (254kb)",
				"southKoreaLow": "South Korea Low (108kb)",
				"spainHigh": "Spain High (194kb)",
				"spainLow": "Spain Low (76kb)",
				"spainProvincesHigh": "Spain Provinces High (474kb)",
				"spainProvincesLow": "Spain Provinces Low (284kb)",
				"sriLankaHigh": "Sri Lanka High (75kb)",
				"sriLankaLow": "Sri Lanka Low (34kb)",
				"stKittsNevisHigh": "ST Kitts Nevis High (18kb)",
				"stKittsNevisLow": "ST Kitts Nevis Low (10kb)",
				"stPierreMiquelonHigh": "ST Pierre Miquelon High (18kb)",
				"stPierreMiquelonLow": "ST Pierre Miquelon Low (7kb)",
				"sudanHigh": "Sudan High (44kb)",
				"sudanLow": "Sudan Low (21kb)",
				"surinameHigh": "Suriname High (24kb)",
				"surinameLow": "Suriname Low (11kb)",
				"svalbardHigh": "Svalbard High (162kb)",
				"svalbardLow": "Svalbard Low (62kb)",
				"swedenHigh": "Sweden High (74kb)",
				"swedenLow": "Sweden Low (32kb)",
				"switzerlandHigh": "Switzerland High (175kb)",
				"switzerlandLow": "Switzerland Low (70kb)",
				"syriaHigh": "Syria High (28kb)",
				"syriaLow": "Syria Low (13kb)",
				"tajikistanHigh": "Tajikistan High (56kb)",
				"tajikistanLow": "Tajikistan Low (22kb)",
				"tanzaniaHigh": "Tanzania High (196kb)",
				"tanzaniaLow": "Tanzania Low (81kb)",
				"thailandHigh": "Thailand High (222kb)",
				"thailandLow": "Thailand Low (97kb)",
				"togoHigh": "Togo High (14kb)",
				"togoLow": "Togo Low (6kb)",
				"tunisiaHigh": "Tunisia High (60kb)",
				"tunisiaLow": "Tunisia Low (27kb)",
				"turkeyHigh": "Turkey High (437kb)",
				"turkeyLow": "Turkey Low (183kb)",
				"turkmenistanHigh": "Turkmenistan High (34kb)",
				"turkmenistanLow": "Turkmenistan Low (15kb)",
				"uaeHigh": "Uae High (58kb)",
				"uaeLow": "Uae Low (26kb)",
				"ukCountiesHigh": "UK Counties High (87kb)",
				"ukCountiesLow": "UK Counties Low (41kb)",
				"ukCountriesHigh": "UK Countries High (156kb)",
				"ukCountriesLow": "UK Countries Low (61kb)",
				"ukHigh": "UK High (641kb)",
				"ukLow": "UK Low (274kb)",
				"ukraineHigh": "Ukraine High (239kb)",
				"ukraineLow": "Ukraine Low (93kb)",
				"unRegionsHigh": "UN Regions High (380kb)",
				"unRegionsLow": "UN Regions Low (133kb)",
				"uruguayHigh": "Uruguay High (65kb)",
				"uruguayLow": "Uruguay Low (27kb)",
				"uzbekistanHigh": "Uzbekistan High (46kb)",
				"uzbekistanLow": "Uzbekistan Low (21kb)",
				"vaticanHigh": "Vatican High (2kb)",
				"vaticanLow": "Vatican Low (771bb)",
				"venezuelaHigh": "Venezuela High (65kb)",
				"venezuelaLow": "Venezuela Low (30kb)",
				"vietnamHigh": "Vietnam High (252kb)",
				"vietnamLow": "Vietnam Low (108kb)",
				"yemenHigh": "Yemen High (56kb)",
				"yemenLow": "Yemen Low (28kb)",
				"zambiaHigh": "Zambia High (77kb)",
				"zambiaLow": "Zambia Low (31kb)",
				"zimbabweHigh": "Zimbabwe High (63kb)",
				"zimbabweLow": "Zimbabwe Low (25kb)"
			},
			"USA": {
				"usaTerritoriesLow": "USA Territories Low (88kb)",
				"usaTerritoriesHigh": "USA Territories High (204kb)",
				"usaTerritories2Low": "USA Territories2 Low (104kb)",
				"usaTerritories2High": "USA Territories2 High (240kb)",
				"usaLow": "USA Low -Recommended- (80kb)",
				"usaHigh": "USA High (184kb)",
				"usaAlbersLow": "USA Albers Low (90kb)",
				"usaAlbersHigh": "USA Albers High (208kb)",
				"region\/usa\/akAlbersHigh": "AK Albers High (783kb)",
				"region\/usa\/akAlbersLow": "AK Albers Low (278kb)",
				"region\/usa\/akHigh": "AK High (701kb)",
				"region\/usa\/akLow": "AK Low (249kb)",
				"region\/usa\/alHigh": "AL High (77kb)",
				"region\/usa\/alLow": "AL Low (38kb)",
				"region\/usa\/arHigh": "AR High (83kb)",
				"region\/usa\/arLow": "AR Low (41kb)",
				"region\/usa\/azHigh": "AZ High (39kb)",
				"region\/usa\/azLow": "AZ Low (16kb)",
				"region\/usa\/caHigh": "CA High (158kb)",
				"region\/usa\/caLow": "CA Low (64kb)",
				"region\/usa\/coHigh": "CO High (64kb)",
				"region\/usa\/coLow": "CO Low (33kb)",
				"region\/usa\/ctHigh": "CT High (10kb)",
				"region\/usa\/ctLow": "CT Low (5kb)",
				"region\/usa\/dcHigh": "DC High (735bb)",
				"region\/usa\/dcLow": "DC Low (431bb)",
				"region\/usa\/deHigh": "DE High (6kb)",
				"region\/usa\/deLow": "DE Low (2kb)",
				"region\/usa\/flHigh": "FL High (149kb)",
				"region\/usa\/flLow": "FL Low (65kb)",
				"region\/usa\/gaHigh": "GA High (396kb)",
				"region\/usa\/gaLow": "GA Low (161kb)",
				"region\/usa\/hiAlbersHigh": "HI Albers High (26kb)",
				"region\/usa\/hiAlbersLow": "HI Albers Low (10kb)",
				"region\/usa\/hiHigh": "HI High (9kb)",
				"region\/usa\/hiLow": "HI Low (4kb)",
				"region\/usa\/iaHigh": "IA High (44kb)",
				"region\/usa\/iaLow": "IA Low (31kb)",
				"region\/usa\/idHigh": "ID High (84kb)",
				"region\/usa\/idLow": "ID Low (36kb)",
				"region\/usa\/ilHigh": "IL High (71kb)",
				"region\/usa\/ilLow": "IL Low (42kb)",
				"region\/usa\/inHigh": "IN High (53kb)",
				"region\/usa\/inLow": "IN Low (34kb)",
				"region\/usa\/ksHigh": "KS High (38kb)",
				"region\/usa\/ksLow": "KS Low (32kb)",
				"region\/usa\/kyHigh": "KY High (108kb)",
				"region\/usa\/kyLow": "KY Low (57kb)",
				"region\/usa\/laHigh": "LA High (150kb)",
				"region\/usa\/laLow": "LA Low (65kb)",
				"region\/usa\/maHigh": "MA High (23kb)",
				"region\/usa\/maLow": "MA Low (10kb)",
				"region\/usa\/mdHigh": "MD High (65kb)",
				"region\/usa\/mdLow": "MD Low (27kb)",
				"region\/usa\/meHigh": "ME High (58kb)",
				"region\/usa\/meLow": "ME Low (24kb)",
				"region\/usa\/miHigh": "MI High (76kb)",
				"region\/usa\/miLow": "MI Low (40kb)",
				"region\/usa\/mnHigh": "MN High (75kb)",
				"region\/usa\/mnLow": "MN Low (42kb)",
				"region\/usa\/moHigh": "MO High (105kb)",
				"region\/usa\/moLow": "MO Low (56kb)",
				"region\/usa\/msHigh": "MS High (56kb)",
				"region\/usa\/msLow": "MS Low (34kb)",
				"region\/usa\/mtHigh": "MT High (97kb)",
				"region\/usa\/mtLow": "MT Low (43kb)",
				"region\/usa\/ncHigh": "NC High (147kb)",
				"region\/usa\/ncLow": "NC Low (70kb)",
				"region\/usa\/ndHigh": "ND High (50kb)",
				"region\/usa\/ndLow": "ND Low (27kb)",
				"region\/usa\/neHigh": "NE High (41kb)",
				"region\/usa\/neLow": "NE Low (30kb)",
				"region\/usa\/nhHigh": "NH High (17kb)",
				"region\/usa\/nhLow": "NH Low (8kb)",
				"region\/usa\/njHigh": "NJ High (36kb)",
				"region\/usa\/njLow": "NJ Low (16kb)",
				"region\/usa\/nmHigh": "NM High (29kb)",
				"region\/usa\/nmLow": "NM Low (16kb)",
				"region\/usa\/nvHigh": "NV High (25kb)",
				"region\/usa\/nvLow": "NV Low (11kb)",
				"region\/usa\/nyHigh": "NY High (65kb)",
				"region\/usa\/nyLow": "NY Low (34kb)",
				"region\/usa\/ohHigh": "OH High (49kb)",
				"region\/usa\/ohLow": "OH Low (33kb)",
				"region\/usa\/okHigh": "OK High (51kb)",
				"region\/usa\/okLow": "OK Low (31kb)",
				"region\/usa\/orHigh": "OR High (96kb)",
				"region\/usa\/orLow": "OR Low (40kb)",
				"region\/usa\/paHigh": "PA High (89kb)",
				"region\/usa\/paLow": "PA Low (41kb)",
				"region\/usa\/riHigh": "RI High (5kb)",
				"region\/usa\/riLow": "RI Low (3kb)",
				"region\/usa\/scHigh": "SC High (69kb)",
				"region\/usa\/scLow": "SC Low (32kb)",
				"region\/usa\/sdHigh": "SD High (44kb)",
				"region\/usa\/sdLow": "SD Low (27kb)",
				"region\/usa\/tnHigh": "TN High (85kb)",
				"region\/usa\/tnLow": "TN Low (45kb)",
				"region\/usa\/txHigh": "TX High (227kb)",
				"region\/usa\/txLow": "TX Low (124kb)",
				"region\/usa\/utHigh": "UT High (48kb)",
				"region\/usa\/utLow": "UT Low (21kb)",
				"region\/usa\/vaHigh": "VA High (158kb)",
				"region\/usa\/vaLow": "VA Low (78kb)",
				"region\/usa\/vtHigh": "VT High (18kb)",
				"region\/usa\/vtLow": "VT Low (9kb)",
				"region\/usa\/waHigh": "WA High (102kb)",
				"region\/usa\/waLow": "WA Low (43kb)",
				"region\/usa\/wiHigh": "WI High (60kb)",
				"region\/usa\/wiLow": "WI Low (33kb)",
				"region\/usa\/wvHigh": "WV High (80kb)",
				"region\/usa\/wvLow": "WV Low (36kb)",
				"region\/usa\/wyHigh": "WY High (22kb)",
				"region\/usa\/wyLow": "WY Low (12kb)"
			},
			"Canada": {
				"region\/canada\/abHigh": "AB High (53kb)",
				"region\/canada\/abLow": "AB Low (24kb)",
				"region\/canada\/bcHigh": "BC High (188kb)",
				"region\/canada\/bcLow": "BC Low (80kb)",
				"region\/canada\/canadaCountiesHigh": "Canada Counties High (550kb)",
				"region\/canada\/canadaCountiesLow": "Canada Counties Low (250kb)",
				"region\/canada\/mbHigh": "MB High (32kb)",
				"region\/canada\/mbLow": "MB Low (16kb)",
				"region\/canada\/nbHigh": "NB High (17kb)",
				"region\/canada\/nbLow": "NB Low (9kb)",
				"region\/canada\/nlHigh": "NL High (118kb)",
				"region\/canada\/nlLow": "NL Low (48kb)",
				"region\/canada\/nsHigh": "NS High (27kb)",
				"region\/canada\/nsLow": "NS Low (13kb)",
				"region\/canada\/ntHigh": "NT High (82kb)",
				"region\/canada\/ntLow": "NT Low (33kb)",
				"region\/canada\/nuHigh": "NU High (431kb)",
				"region\/canada\/nuLow": "NU Low (163kb)",
				"region\/canada\/onHigh": "ON High (93kb)",
				"region\/canada\/onLow": "ON Low (47kb)",
				"region\/canada\/peHigh": "PE High (4kb)",
				"region\/canada\/peLow": "PE Low (2kb)",
				"region\/canada\/qcHigh": "QC High (173kb)",
				"region\/canada\/qcLow": "QC Low (85kb)",
				"region\/canada\/skHigh": "SK High (22kb)",
				"region\/canada\/skLow": "SK Low (11kb)",
				"region\/canada\/ytHigh": "YT High (11kb)",
				"region\/canada\/ytLow": "YT Low (4kb)"
			},
			"Mexico": {
				"region\/mexico\/agsHigh": "Ags High (34kb)",
				"region\/mexico\/agsLow": "Ags Low (15kb)",
				"region\/mexico\/bcnHigh": "Bcn High (70kb)",
				"region\/mexico\/bcnLow": "Bcn Low (28kb)",
				"region\/mexico\/bcsHigh": "Bcs High (51kb)",
				"region\/mexico\/bcsLow": "Bcs Low (21kb)",
				"region\/mexico\/camHigh": "Cam High (43kb)",
				"region\/mexico\/camLow": "Cam Low (19kb)",
				"region\/mexico\/chhHigh": "Chh High (141kb)",
				"region\/mexico\/chhLow": "Chh Low (67kb)",
				"region\/mexico\/chpHigh": "Chp High (142kb)",
				"region\/mexico\/chpLow": "Chp Low (77kb)",
				"region\/mexico\/cmxHigh": "Cmx High (49kb)",
				"region\/mexico\/cmxLow": "Cmx Low (21kb)",
				"region\/mexico\/coaHigh": "Coa High (77kb)",
				"region\/mexico\/coaLow": "Coa Low (38kb)",
				"region\/mexico\/colHigh": "Col High (63kb)",
				"region\/mexico\/colLow": "Col Low (26kb)",
				"region\/mexico\/durHigh": "Dur High (79kb)",
				"region\/mexico\/durLow": "Dur Low (37kb)",
				"region\/mexico\/groHigh": "Gro High (136kb)",
				"region\/mexico\/groLow": "Gro Low (67kb)",
				"region\/mexico\/guaHigh": "Gua High (78kb)",
				"region\/mexico\/guaLow": "Gua Low (39kb)",
				"region\/mexico\/hidHigh": "Hid High (138kb)",
				"region\/mexico\/hidLow": "Hid Low (68kb)",
				"region\/mexico\/jalHigh": "Jal High (278kb)",
				"region\/mexico\/jalLow": "Jal Low (129kb)",
				"region\/mexico\/mexHigh": "Mex High (150kb)",
				"region\/mexico\/mexLow": "Mex Low (81kb)",
				"region\/mexico\/mexicoCountiesHigh": "Mexico Counties High (2mb)",
				"region\/mexico\/mexicoCountiesLow": "Mexico Counties Low (1mb)",
				"region\/mexico\/mexicoCountiesUltra": "Mexico Counties Ultra (3mb)",
				"region\/mexico\/micHigh": "Mic High (187kb)",
				"region\/mexico\/micLow": "Mic Low (94kb)",
				"region\/mexico\/morHigh": "Mor High (85kb)",
				"region\/mexico\/morLow": "Mor Low (41kb)",
				"region\/mexico\/nayHigh": "Nay High (53kb)",
				"region\/mexico\/nayLow": "Nay Low (24kb)",
				"region\/mexico\/nleHigh": "Nle High (85kb)",
				"region\/mexico\/nleLow": "Nle Low (41kb)",
				"region\/mexico\/oaxHigh": "Oax High (383kb)",
				"region\/mexico\/oaxLow": "Oax Low (261kb)",
				"region\/mexico\/pueHigh": "Pue High (318kb)",
				"region\/mexico\/pueLow": "Pue Low (162kb)",
				"region\/mexico\/queHigh": "Que High (45kb)",
				"region\/mexico\/queLow": "Que Low (21kb)",
				"region\/mexico\/rooHigh": "Roo High (56kb)",
				"region\/mexico\/rooLow": "Roo Low (25kb)",
				"region\/mexico\/sinHigh": "Sin High (75kb)",
				"region\/mexico\/sinLow": "Sin Low (31kb)",
				"region\/mexico\/slpHigh": "Slp High (103kb)",
				"region\/mexico\/slpLow": "Slp Low (51kb)",
				"region\/mexico\/sonHigh": "Son High (78kb)",
				"region\/mexico\/sonLow": "Son Low (43kb)",
				"region\/mexico\/tabHigh": "Tab High (91kb)",
				"region\/mexico\/tabLow": "Tab Low (37kb)",
				"region\/mexico\/tamHigh": "Tam High (71kb)",
				"region\/mexico\/tamLow": "Tam Low (35kb)",
				"region\/mexico\/tlaHigh": "Tla High (62kb)",
				"region\/mexico\/tlaLow": "Tla Low (35kb)",
				"region\/mexico\/verHigh": "Ver High (344kb)",
				"region\/mexico\/verLow": "Ver Low (174kb)",
				"region\/mexico\/yucHigh": "Yuc High (79kb)",
				"region\/mexico\/yucLow": "Yuc Low (50kb)",
				"region\/mexico\/zacHigh": "Zac High (101kb)",
				"region\/mexico\/zacLow": "Zac Low (49kb)"
			}
		}';

		$this->maps = apply_filters( 'igm_map_list_json', $json );
	}
}
